@@ -31,7 +31,6 @@ class DisplayManager:
         show_banner: bool = True,
         show_metadata: bool = False,
         use_rich: bool = False,
-        auto_save: bool = False,
         config: Any = None,
         status_bar: Any = None,
     ):
@@ -45,7 +44,6 @@ class DisplayManager:
             show_banner: Whether to show banner
             show_metadata: Whether to show metadata in banner
             use_rich: Whether rich formatting is enabled
-            auto_save: Whether auto-save is enabled
             config: Configuration object
             status_bar: StatusBar instance
         """
@@ -55,7 +53,6 @@ class DisplayManager:
         self.show_banner = show_banner
         self.show_metadata = show_metadata
         self.use_rich = use_rich
-        self.auto_save = auto_save
         self.config = config
         self.status_bar = status_bar
 
@@ -99,16 +96,18 @@ class DisplayManager:
 
         print()
         print("Commands:")
-        print("  help      - Show this help message")
-        print("  info      - Show detailed agent information")
-        print("  templates - List available prompt templates")
-        print("  sessions  - List saved conversation sessions")
-        print("  /name     - Use prompt template from ~/.prompts/name.md")
-        print("  resume <#>- Resume a previous session by number or ID")
-        print("  copy      - Copy last response to clipboard")
-        print("  clear     - Clear screen and reset agent session")
-        print("  quit      - Exit the chat")
-        print("  exit      - Exit the chat")
+        print("  #help       - Show this help message")
+        print("  #info       - Show detailed agent information")
+        print("  #context    - Show token usage and context statistics")
+        print("  #templates  - List available prompt templates")
+        print("  #sessions   - List saved conversation sessions")
+        print("  /name       - Use prompt template from ~/.prompts/name.md")
+        print("  #resume <#> - Resume a previous session by number or ID")
+        print("  #compact    - Save session and continue in new session with summary")
+        print("  #copy       - Copy last response to clipboard")
+        print("  #clear      - Clear screen and reset agent session")
+        print("  #quit       - Exit the chat")
+        print("  #exit       - Exit the chat")
         print()
         print("Features:")
         if READLINE_AVAILABLE:
@@ -125,13 +124,7 @@ class DisplayManager:
         if self.config:
             print()
             print(Colors.DIM + "Configuration loaded" + Colors.RESET)
-            if self.auto_save:
-                save_loc = self.config.get(
-                    "paths.save_location",
-                    "~/agent-conversations",
-                    agent_name=self.agent_name,
-                )
-                print(f"  Auto-save: enabled → {save_loc}")
+            print("  Auto-save: always enabled → ./.chat-sessions")
 
         print("=" * 60)
 
@@ -143,31 +136,31 @@ class DisplayManager:
         print(f"Description: {self.agent_description}")
         print()
         print("Commands:")
-        print("  help      - Show this help message")
-        print("  info      - Show detailed agent information")
-        print("  templates - List available prompt templates")
-        print("  sessions  - List saved conversation sessions")
-        print("  save      - Save conversation (update or new snapshot)")
-        print("  /name     - Use prompt template from ~/.prompts/name.md")
-        print("  resume <#>- Resume a previous session by number or ID")
-        print("  copy      - Copy last response to clipboard")
-        print("  clear     - Clear screen and reset agent session")
-        print("  quit      - Exit the chat")
-        print("  exit      - Exit the chat")
+        print("  #help       - Show this help message")
+        print("  #info       - Show detailed agent information")
+        print("  #context    - Show token usage and context statistics")
+        print("  #templates  - List available prompt templates")
+        print("  #sessions   - List saved conversation sessions")
+        print("  /name       - Use prompt template from ~/.prompts/name.md")
+        print("  #resume <#> - Resume a previous session by number or ID")
+        print("  #compact    - Save session and continue in new session with summary")
+        print("  #copy       - Copy last response to clipboard")
+        print("  #clear      - Clear screen and reset agent session")
+        print("  #quit       - Exit the chat")
+        print("  #exit       - Exit the chat")
         print()
         print("Session Management:")
-        print("  sessions  - See all saved conversations")
-        print("  save      - Save conversation now (update or new snapshot)")
-        print("  save <name> - Save with custom name")
-        print("  resume 1  - Resume session by number from list")
-        print("  resume ID - Resume session by full ID")
-        print("  Auto-save - Enabled with --auto-save or in config")
+        print("  #sessions  - See all saved conversations")
+        print("  #resume 1  - Resume session by number from list")
+        print("  #resume ID - Resume session by full ID")
+        print("  #compact   - Save current session and start new with summary")
+        print("  Auto-save  - Always enabled (saves after each message)")
         print()
         print("Copy Commands:")
-        print("  copy       - Copy last response to clipboard")
-        print("  copy query - Copy your last query")
-        print("  copy all   - Copy entire conversation as markdown")
-        print("  copy code  - Copy code blocks from last response")
+        print("  #copy       - Copy last response to clipboard")
+        print("  #copy query - Copy your last query")
+        print("  #copy all   - Copy entire conversation as markdown")
+        print("  #copy code  - Copy code blocks from last response")
         print()
         print("Prompt Templates:")
         print("  Create: Save markdown files to ~/.prompts/name.md")
@@ -234,8 +227,7 @@ class DisplayManager:
         print("  ✓ Session reset with 'clear' command")
         if self.config:
             print("  ✓ Configuration file support (~/.chatrc or .chatrc)")
-        if self.auto_save:
-            print("  ✓ Auto-save conversations on exit")
+        print("  ✓ Auto-save conversations after each message")
         print("=" * 60)
 
     def display_session_summary(
@@ -352,7 +344,7 @@ class DisplayManager:
             print(f"{Colors.DIM}{preview_text}{Colors.RESET}")
 
         print(f"{Colors.DIM}{'-' * 60}{Colors.RESET}")
-        print(Colors.system("Use: resume <number> or resume <session_id>"))
+        print(Colors.system("Use: #resume <number> or #resume <session_id>"))
 
     def display_session_loaded(self, session_info, query_count: int):
         """
